@@ -28,6 +28,7 @@ from .protocol import (
     PROTOCOL_LEDENET_ADDRESSABLE_A1,
     PROTOCOL_LEDENET_ADDRESSABLE_A2,
     PROTOCOL_LEDENET_ADDRESSABLE_A3,
+    PROTOCOL_LEDENET_ADDRESSABLE_CHRISTMAS,
     PROTOCOL_LEDENET_CCT,
     PROTOCOL_LEDENET_ORIGINAL,
 )
@@ -274,13 +275,22 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x06,
-        # "AK001-ZJ2145" == v2
-        # "AK001-ZJ2147" == v3
-        # AK001-ZJ2147 has RF remote support
-        models=["AK001-ZJ100", "AK001-ZJ200", "AK001-ZJ2145", "AK001-ZJ2147"],
+        # "AK001-ZJ2104" == v1 has RF remote support
+        # "AK001-ZJ2145" == v2 has IR remote support
+        # "AK001-ZJ2147" == v3 has RF remote support
+        models=[
+            "AK001-ZJ100",
+            "AK001-ZJ200",
+            "AK001-ZJ2104",
+            "AK001-ZJ2145",
+            "AK001-ZJ2147",
+        ],
         description="Controller RGBW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
-        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS)],
+        protocols=[
+            MinVersionProtocol(2, PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS),
+            MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE),
+        ],
         mode_to_color_mode=GENERIC_RGBW_MAP,
         color_modes={COLOR_MODE_RGBW},  # Formerly rgbwcapable
         channel_map={},
@@ -288,12 +298,14 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x07,
-        # "AK001-ZJ2146" == v2
-        # AK001-ZJ2146 has RF remote support
+        # "AK001-ZJ2146" == v2 has RF remote support
         models=["AK001-ZJ2146"],
         description="Controller RGBCW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
-        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_9BYTE_DIMMABLE_EFFECTS)],
+        protocols=[
+            MinVersionProtocol(2, PROTOCOL_LEDENET_9BYTE_DIMMABLE_EFFECTS),
+            MinVersionProtocol(0, PROTOCOL_LEDENET_9BYTE),
+        ],
         mode_to_color_mode=GENERIC_RGBWW_MAP,
         color_modes={COLOR_MODE_RGBWW},  # Formerly rgbwcapable
         channel_map={},
@@ -301,10 +313,15 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x08,
-        models=["AK001-ZJ2147"],
+        # AK001-ZJ2101 is v1
+        # AK001-ZJ2145 is v2
+        models=["AK001-ZJ2101", "AK001-ZJ2145", "AK001-ZJ2147"],
         description="Controller RGB with MIC",
         always_writes_white_and_colors=True,  # Formerly rgbwprotocol
-        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS)],
+        protocols=[
+            MinVersionProtocol(2, PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS),
+            MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE),
+        ],
         mode_to_color_mode=GENERIC_RGB_MAP,
         color_modes={COLOR_MODE_RGB},
         channel_map={},
@@ -358,20 +375,20 @@ MODELS = [
         models=[],
         description="Christmas Light",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
-        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
+        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_ADDRESSABLE_CHRISTMAS)],
         mode_to_color_mode={},
-        color_modes={COLOR_MODE_RGB},  # Formerly rgbwcapable
+        color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
         microphone=False,
     ),
     LEDENETModel(
         model_num=0x1A,
-        models=[],
+        models=["AK001-ZJ2147"],
         description="Christmas Light",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
-        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
+        protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_ADDRESSABLE_CHRISTMAS)],
         mode_to_color_mode={},
-        color_modes={COLOR_MODE_RGB},  # Formerly rgbwcapable
+        color_modes=COLOR_MODES_ADDRESSABLE,
         channel_map={},
         microphone=False,
     ),
@@ -466,6 +483,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x25,
+        # 'AK001-ZJ200' == v2 - some devices have RF remote support (the mini ones)
         models=["HF-LPB100-ZJ200", "AK001-ZJ200"],
         description="Controller RGB/WW/CW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
@@ -477,6 +495,7 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x33,
+        # 'AK001-ZJ100' == v3 - WIFI370 version
         # 'AK001-ZJ2104' == v7 supports turning on by effect/levels set
         # 'AK001-ZJ2101' == v8
         # "AK001-ZJ2145" == v9 # no rf support!
@@ -507,8 +526,15 @@ MODELS = [
         # 'AK001-ZJ2101' and 'AK001-ZJ2104' is v7
         # 'AK001-ZJ2145' is v8
         # 'AK001-ZJ2146' is v9
+        # 'AK001-ZJ2147' is v9.7
         # 'AK001-ZJ2146' 40w flood light, newer smart bulbs (with RF remote control support)
-        models=["AK001-ZJ2101", "AK001-ZJ2104", "AK001-ZJ2145", "AK001-ZJ2146"],
+        models=[
+            "AK001-ZJ2101",
+            "AK001-ZJ2104",
+            "AK001-ZJ2145",
+            "AK001-ZJ2146",
+            "AK001-ZJ2147",
+        ],
         description="Bulb RGBCW",
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[
@@ -615,7 +641,8 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x93,
-        models=[],
+        # AK001-ZJ2146 == v3
+        models=["AK001-ZJ2146"],
         description="Switch",  # 1 channel
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
@@ -659,7 +686,8 @@ MODELS = [
     ),
     LEDENETModel(
         model_num=0x97,  # 0x97
-        models=["AK001-ZJ2134"],
+        # AK001-ZJ2146 = v3 (has BLE)
+        models=["AK001-ZJ2134", "AK001-ZJ2146"],
         description="Socket",  # 1 channel
         always_writes_white_and_colors=False,  # Formerly rgbwprotocol
         protocols=[MinVersionProtocol(0, PROTOCOL_LEDENET_8BYTE)],
