@@ -23,6 +23,7 @@ EFFECT_CYAN_STROBE = "cyan_strobe"
 EFFECT_PURPLE_STROBE = "purple_strobe"
 EFFECT_WHITE_STROBE = "white_strobe"
 EFFECT_CYCLE_RGB = "cycle_rgb"
+EFFECT_CYCLE_SEVEN_COLORS = "cycle_seven_colors"
 EFFECT_COLORJUMP = "colorjump"
 EFFECT_CUSTOM = "custom"
 
@@ -51,6 +52,10 @@ EFFECT_MAP = {
 EFFECT_MAP_DIMMABLE = {
     **EFFECT_MAP,
     EFFECT_CYCLE_RGB: 0x39,
+    EFFECT_CYCLE_SEVEN_COLORS: 0x3A,
+    # cycle_seven_colors Doesn't work on the bulbs, but no way to tell ahead of time
+    # since the firmware version is v9 for both but it seems like only the AK001-ZJ2147
+    # model actually has support for it
 }
 
 EFFECT_ID_NAME = {v: k for k, v in EFFECT_MAP_DIMMABLE.items()}
@@ -486,6 +491,116 @@ ORIGINAL_ADDRESSABLE_EFFECT_NAME_ID = {
 }
 
 
+CHRISTMAS_ADDRESSABLE_EFFECT_ID_NAME = {
+    1: "Random Jump Async",
+    2: "Random Gradient Async",
+    3: "Fill-in Red, Green",
+    4: "Fill-in Green, Blue",
+    5: "Fill-in Green, Yellow",
+    6: "Fill-in Green, Cyan",
+    7: "Fill-in Green, White",
+    8: "Fill-in Green, Red",
+    9: "Twinkle Red",
+    10: "Twinkle Green",
+    11: "Twinkle Yellow",
+    12: "Twinkle Blue",
+    13: "Twinkle Purple",
+    14: "Twinkle Cyan",
+    15: "Twinkle White",
+    16: "Alternating Flash Red, Green, Blue",
+    17: "Alternating Flash Red, Green",
+    18: "Alternating Flash Green, Blue",
+    19: "Alternating Flash Blue, Yellow",
+    20: "Alternating Flash Yellow, Cyan",
+    21: "Alternating Flash Cyan, Purple",
+    22: "Alternating Flash Purple, White",
+    23: "Wave Seven-Color",
+    24: "Wave RGB",
+    25: "Wave Red",
+    26: "Wave Green",
+    27: "Wave Yellow",
+    28: "Wave Blue",
+    29: "Wave Purple",
+    30: "Wave Cyan",
+    31: "Wave White",
+    32: "Breathe Sync Seven-Color",
+    33: "Breathe Sync RGB",
+    34: "Breathe Sync Red, Green",
+    35: "Breathe Sync Red, Blue",
+    36: "Breathe Sync Green, Blue",
+    37: "Breathe Sync Red",
+    38: "Breathe Sync Green",
+    39: "Breathe Sync Yellow",
+    40: "Breathe Sync Blue",
+    41: "Breathe Sync Purple",
+    42: "Breathe Sync Cyan",
+    43: "Breathe Sync White",
+    44: "Fill-in and Reset Red, Green",
+    45: "Fill-in and Reset Green, Blue",
+    46: "Fill-in and Reset Blue, Yellow",
+    47: "Fill-in and Reset Yellow, Cyan",
+    48: "Fill-in and Reset Cyan, Purple",
+    49: "Fill-in and Reset Purple, White",
+    50: "Fill-in and Reset Red, Green, Blue, Yellow",
+    51: "Fill-in and Reset Red, Blue, Green, White",
+    52: "Fill-in and Reset Blue, White, Purple, Yellow",
+    53: "Fill-in and Reset White, Purple, Cyan, Green",
+    54: "Strobe Red, Green, Blue, Yellow, Cyan, Purple, White",
+    55: "Strobe Green, Red, Blue, Yellow, Cyan, Purple, White",
+    56: "Strobe Blue, Green, Red, Yellow, Cyan, Purple, White",
+    57: "Strobe Yellow, Green, Blue, Red, Cyan, Purple, White",
+    58: "Strobe Cyan, Green, Blue, Yellow, Red, Purple, White",
+    59: "Strobe Purple, Green, Blue, Yellow, Cyan, Red, White",
+    60: "Strobe White, Green, Blue, Yellow, Cyan, Purple, Red",
+    61: "Strobe Red, Green",
+    62: "Strobe Green, Blue",
+    63: "Strobe Blue, Yellow",
+    64: "Strobe Yellow, Cyan",
+    65: "Strobe Cyan, Purple",
+    66: "Strobe Purple, White",
+    67: "Strobe Black, White",
+    68: "Flash Sync Seven-color",
+    69: "Flash Sync RGB",
+    70: "Flash Sync Red",
+    71: "Flash Sync Green",
+    72: "Flash Sync Yellow",
+    73: "Flash Sync Blue",
+    74: "Flash Sync Purple",
+    75: "Flash Sync Cyan",
+    76: "Jump Sync Seven-color",
+    77: "Jump Sync RGB",
+    78: "Jump Sync Red",
+    79: "Jump Sync Green",
+    80: "Jump Sync Yellow",
+    81: "Jump Sync Blue",
+    82: "Jump Sync Purple",
+    83: "Jump Sync Cyan",
+    84: "Red Wave, Breathe Sync, Flash, Jump",
+    85: "Green Wave, Breathe Sync, Flash, Jump",
+    86: "Yellow Wave, Breathe Sync, Flash, Jump",
+    87: "Blue Wave, Breathe Sync, Flash, Jump",
+    88: "Purple Wave, Breathe Sync, Flash, Jump",
+    89: "Cyan Wave, Breathe Sync, Flash, Jump",
+    90: "White Wave, Breathe Sync, Flash, Jump",
+    91: "Seven-color Wave, Breathe Sync",
+    92: "Seven-color Breathe Sync, Flash Sync",
+    93: "Seven-color Flash Sync, Jump Sync",
+    93: "Seven-color Flash Sync, Jump Sync",
+    93: "Seven-color Flash Sync, Jump Sync",
+    94: "Seven-color Wave, Breathe Sync, Flash Sync, Jump Sync",
+    95: "Overlap Red, Green, Blue",
+    96: "Overlap Red, Green, Blue, Cyan, Purple, White",
+    97: "Overlap Green, Blue, Cyan",
+    98: "Overlap Blue, Cyan, Purple",
+    99: "Overlap Cyan, Purple, White",
+    100: "Overlap White, Black, Red",
+}
+
+CHRISTMAS_ADDRESSABLE_EFFECT_NAME_ID = {
+    v: k for k, v in CHRISTMAS_ADDRESSABLE_EFFECT_ID_NAME.items()
+}
+
+
 class PresetPattern:
     _instance = None
     seven_color_cross_fade = EFFECT_MAP[EFFECT_COLORLOOP]
@@ -509,6 +624,7 @@ class PresetPattern:
     white_strobe_flash = EFFECT_MAP[EFFECT_WHITE_STROBE]
     seven_color_jumping = EFFECT_MAP[EFFECT_COLORJUMP]
     cycle_rgb = EFFECT_MAP_DIMMABLE[EFFECT_CYCLE_RGB]
+    cycle_seven_colors = EFFECT_MAP_DIMMABLE[EFFECT_CYCLE_SEVEN_COLORS]
 
     def __init__(self) -> None:
         self._value_to_str: Dict[int, str] = {
@@ -526,7 +642,7 @@ class PresetPattern:
 
     @staticmethod
     def valid(pattern: int) -> bool:
-        if pattern >= 0x25 and pattern <= 0x39 or pattern >= 0x61 and pattern <= 0x63:
+        if pattern >= 0x25 and pattern <= 0x3A or pattern >= 0x61 and pattern <= 0x63:
             return True
         return False
 
